@@ -7,7 +7,6 @@ import time
 
 import imgui
 from imgui.integrations.glfw import GlfwRenderer
-from contextlib import contextmanager
 
 from concur.integrations.opengl import create_offscreen_fb, get_fb_data
 
@@ -87,23 +86,12 @@ def create_window_dock(glfw_window, menu_bar=False):
     imgui.end()
 
 
-@contextmanager
-def managed_resource():
-    # Code to acquire resource, e.g.:
-    resource = acquire_resource(*args, **kwds)
-    try:
-        yield resource
-    finally:
-        # Code to release resource, e.g.:
-        release_resource(resource)
-
-
 def main(widget, name="Concur", width=640, height=480, fps=60, save_screencast=None, screencast_fps=60, menu_bar=False):
     """ Create a GLFW window, spin up the main loop, and display a given widget inside.
 
     To create a maximized window, pass width and height larger than the screen.
 
-    Arguments:
+    Args:
         widget: The widget to display inside the window. When the widget returns, the application exits.
         name: Window name, displayed in the title bar and other OS outputs.
         width: Desired window width.
